import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const jwt = require('jsonwebtoken');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
const company = [
  {
    path: '/companyCenter/basic',
    name: 'companyCenter_basic',
    meta: { title: '基本信息' },
    component: () => import('../views/companyCenter/basic/index.vue'),
  },
  {
    path: '/companyCenter/subsidy',
    name: 'companyCenter_subsidy',
    meta: { title: '研发补贴' },
    component: () => import('../views/companyCenter/subsidy/index.vue'),
  },
  {
    path: '/companyCenter/subsidy/detail',
    name: 'companyCenter_subsidy_detail',
    meta: { title: '研发补贴-信息管理' },
    component: () => import('../views/companyCenter/subsidy/detail.vue'),
  },
  {
    path: '/companyCenter/reward',
    name: 'companyCenter_reward',
    meta: { title: '奖励兑现' },
    component: () => import('../views/companyCenter/reward/index.vue'),
  },
  {
    path: '/companyCenter/reward/detail',
    name: 'companyCenter_reward_detail',
    meta: { title: '奖励兑现-信息管理' },
    component: () => import('../views/companyCenter/reward/detail.vue'),
  },
  {
    path: '/companyCenter/coupons',
    name: 'companyCenter_coupons',
    meta: { title: '创新券申领' },
    component: () => import('../views/companyCenter/coupons/index.vue'),
  },
  {
    path: '/companyCenter/coupons/detail',
    name: 'companyCenter_coupons_detail',
    meta: { title: '创新券-信息管理' },
    component: () => import('../views/companyCenter/coupons/detail.vue'),
  },
];
const web = [
  {
    path: '/',
    name: 'index',
    meta: { title: '网站首页' },
    component: () => import('../views/index.vue'),
  },
  {
    path: '/policy',
    name: 'policy_index',
    meta: { title: '高企政策服务' },
    component: () => import('../views/policy/index.vue'),
  },
  {
    path: '/ticket',
    name: 'ticket_index',
    meta: { title: '高企申报服务' },
    component: () => import('../views/ticket/index.vue'),
  },
  {
    path: '/userCenter',
    name: 'userCenter_index',
    meta: { title: '个人中心' },
    component: () => import('../views/userCenter/index.vue'),
  },
  {
    path: '/login',
    name: 'login',
    meta: { title: '登录页面' },
    component: () => import('../views/login.vue'),
  },
  // 企业菜单
  ...company,
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.path == '/policy' || to.path == '/ticket' || to.path == '/userCenter') {
    if (!token) {
      next(`/login?path=${to.path}`);
    } else {
      let user = jwt.decode(token);
      store.commit('setUser', user, { root: true });
      next();
    }
  } else {
    let user = jwt.decode(token);
    store.commit('setUser', user, { root: true });
    next();
  }
});

export default router;
